﻿using Microsoft.Win32;
using System;
using System.IO;
using System.Net;
using System.Windows;
using System.Windows.Media.Imaging;

/*
 *         Progetto: HTTP Storage 
 * 
 *           Autore: Roberto Fuligni
 *  Ultima modifica: 20/11/2015
 *  
 *      Descrizione: Modulo client - Effettua l'upload di un file
 *                   al server mediante il metodo POST includendo 
 *                   il contenuto della risorsa nel body HTTP.
 */

namespace HTTPStorageClient
{
    /// <summary>
    /// Logica di interazione per MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        const string UriServer = "http://localhost:8080/Upload.aspx?nomefile=";

        private OpenFileDialog fileDialog = new OpenFileDialog() { Filter = "Tutti i file (*.*)|*.*" };
        private string nomeFile;
        private string nomeFileCompleto;

        public MainWindow()
        {
            InitializeComponent();
        }

        private void btnSfoglia_Click(object sender, RoutedEventArgs e)
        {
            
            bool? flagOk = fileDialog.ShowDialog();
            if (flagOk.HasValue & flagOk.Value == true)
            {
                nomeFileCompleto = fileDialog.FileName;
                nomeFile = fileDialog.SafeFileName;
                tbNomeFile.Text = nomeFileCompleto;
            }

        }

        private async void btnInvia_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                HttpWebRequest req = (HttpWebRequest) WebRequest.Create(UriServer + nomeFile);
                req.Method = "POST";

                using (Stream fs = File.OpenRead(nomeFileCompleto))
                {
                    Stream streamReq = await req.GetRequestStreamAsync();

                    byte[] dataByte = new byte[1024];
                    int i;
                    do
                    {
                        i = await fs.ReadAsync(dataByte, 0, 1024);
                        if (i > 0)
                            await streamReq.WriteAsync(dataByte, 0, i);
                    } while (i > 0);
                }

                HttpWebResponse response = (HttpWebResponse) await req.GetResponseAsync();
                Stream streamResp = response.GetResponseStream();
                StreamReader streamRead = new StreamReader(streamResp);
                var responseString = streamRead.ReadToEnd();
 
                streamRead.Close();
                streamResp.Close();
                response.Close();

                MessageBox.Show(responseString, "Risposta HTTP", MessageBoxButton.OK, MessageBoxImage.Information);
            }
            catch (Exception ex)
            {
                MessageBox.Show(String.Format("Errore nell'invuio del file: {0}", ex.Message), "Errore", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }

    }
}
