﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

/*
 *         Progetto: HTTP Storage 
 * 
 *           Autore: Roberto Fuligni
 *  Ultima modifica: 20/11/2015
 *  
 *      Descrizione: Modulo server - Riceve una richiesta HTTP, basata sul 
 *                   metodo POST, contenente una risorsa da memorizzare nella cartella "Storage".
 *                   Restituisce una risposta con status code 201 (created) oppure 500 (Errore di
 *                   elaborazione del server).
 *                   
 *   Per avviare l'applicazione web dal prompt dei comandi:
 *                  C:\Program Files\IIS Express\iisexpress.exe /path:"C:\HTTPStorage\HTTPStorageServer"
 */

namespace HTTPStorageServer
{
    public partial class Upload : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            Response.Clear();
            try
            {
                string nomeFile = MemorizzaFile();
                Response.StatusCode = 201;
                Response.AddHeader("Location", Page.ResolveUrl(String.Format("~/Storage/{0}", nomeFile)));
                Response.Write(String.Format("<h1>Risorsa {0} creata</h1>", nomeFile));

            }
            catch (Exception ex)
            {
                Response.StatusCode = 500;
                Response.Write(String.Format("<h1>Errore durante l&rsquo;elaborazione della risorsa</h1> <p style='color: red;'>{0}</p>", ex.Message));
            }

            Response.End();
        }

        private string MemorizzaFile()
        {
            string nomeFile = Request.QueryString["nomefile"];

            if (nomeFile != null) nomeFile = nomeFile.Trim();

            if (nomeFile == null || nomeFile.Length == 0)
                throw new Exception("Nome del file mancante.");

            string percorso = HttpContext.Current.Request.PhysicalApplicationPath;
            string nomeCompleto = String.Format(@"{0}Storage\{1}", percorso, nomeFile);

            if (File.Exists(nomeCompleto))
                throw new Exception("Il nome specificato è già presente nello storage.");

            using (FileStream fs = File.OpenWrite(nomeCompleto))
            {
                byte[] buffer = new byte[1024];
                int i;
                do
                {
                    i = Request.InputStream.Read(buffer, 0, 1024);
                    if (i > 0)
                        fs.Write(buffer, 0, i);
                }
                while (i > 0);
            }

            return nomeFile;
        }
    }
}